@@ -1,6 +1,7 @@
 c         hadoron-A collision.  generic.
       subroutine chAcol(pj, ia, iz, a, ntp)
       implicit none
+#include  "Zcondc.h"
 #include  "Zcode.h"
 #include  "Zptcl.h"
 #include  "Zevhnp.h"
@@ -46,5 +47,14 @@ c            h-A collision  Fermi momentum is considered inside
          else
             call chAcolAdhoc(pj, ia, iz, a, ntp)
          endif
+#if INCLUSIVE == 1
+      elseif(IntModel .eq. 'inclusive') then
+c                 air target is fixed as N in this case.
+         call cinclusive(pj, a, ntp)
+#endif
+      else
+         call cerrorMsg('IntModel=', 1)
+         call cerrorMsg(IntModel, 1)
+         call cerrorMsg(' is undefined', 0)
       endif
       end
