@@ -14,15 +14,22 @@ c	(->  ---------------------------------------------
         real*8  Kpicns  !2  See Kpilog.
         real*8  Elund   !2  E < Elund==> Lund M.C is used. in h-n. (IntModel='int1'). If IntModel='int2'
                         !   ==>Gheisha is used.  Elund can be as small as 4.99. (Default is  500.
-                        !   For NEXT 4.99).
+                        !   For Absoft Fortran 4.99).
         real*8  Elund2  !2  Elund < E < Elund2 ==> ad hoc model is used; Elund2 must be > ~100, if Elund2 < Elund3.
                         !   Defualt is Elund
         real*8  Elund3  !2  Elund2< E < Elund3 ==> New Lund Fritiof is used. Elund3 can be < Elund2
                         !   If E > Elund3,  ad hoc model is used.  Default is Elund.
 	real*8  Efermi   !2 If Kinetic E < Efermi, Fermi Momentum is considered for Nucleus target.
-        character*6  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
+        character*16  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
                        ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
                        ! at low energies. (See, Elund?).
+                       !  If 'inclusive', an inclusive treatment is employed as given in Contrib/Inclusive.
+                       !  To make this work actually, INCLUSIVE in cosmos/Zcondc.h must be given a value of 1
+                       !  when making the cosmos library.  At execution time, InclusiveFile must be given
+                       !  the path to the xdist.d file. (normally in Contrib/Inclusive/xdist.d)
+                       !  The treatmen is one dimesional. May be used for neutrino calculations.
+        character*100 InclusiveFile !2 The path to the inclusive data file, xdist.d. Default is
+                       !   "../Contrib/Inclusive/xdist.d"
         real*8 SucPw   !2  In the 2nd, 3rd,.. collision of a nucleon inside a nucleus, the collision is 
                        !  made to be more elastic than normal one. The leading particle spectrum is
                        ! sampled from x**SucPw dx. SucPw should be in 1 to 2.
@@ -46,7 +53,7 @@ c	<-)     -----------------------------
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
      *         LundPara(10), SucInt
-        common /Zevhnc/ IntModel 
+        common /Zevhnc/ InclusiveFile, IntModel 
 c                 this should be in block common. 
 c        data  Cepic0/0.3d0/, Cekaon/0.d0/, Ceneuc/0.35d0/,
 c    *         Mudirp/1.d0/, Kpilog/0.0062/, Kpicns/0.077/,
