@@ -22,14 +22,12 @@ c	(->	------------------------------------
                                    !             follow particles to a lower energy and/or to a deeper depth.
 	                           !             The namelist parameters you give should be 'skeletonParam'
 	                           !             with some necessary modification.
-        character*70  SeedFile     !1  Files containing the initial random numbers for those events to which you 
-                                   !   want to flesh.  You can create the file by calling  cwriteSeed in a
-                                   !   user hook routine (say, in chookEnEvent) at skeleton making time.
-                                   !   default is '../Data/seed'.
-                                   !   If you want to create the file not at the time of making skeleton,
-                                   !   you have to write  two integer initial random numbers, 
-	                           !   and the event number (and more optional ones) 
-                                   !   This file is opened automatically, if needed.
+        character*70  SeedFile     !1  The path to a file name to contain the initial random numbers for each 
+                                   !   event. If this is non-blank, the seeds are always writen in this file.
+                                   !   If your job is skeleton making or fleshing, this must be given.
+                                   !   Default is '../Data/seed'.
+                                   !   This file is opened automatically.  This will help when a job
+                                   !   crashes.
         integer       SeedFileDev  !2   logical device number of SeedFile.
 	logical       Cont         !1  If T, continuation from a previous job is assumed. Contfile content is used.
 	integer       InitRN       !1  Initial random number seed. 2 integers.
