@@ -9,11 +9,12 @@ c         by putting  Es = 0.
      +, Elund, Elund2, Elund3, EndLevel, EndLevel2, ErrorOut, Es
      +, Eta2Pi0, EthinRatio, EventNo, EventsInTheRun, ExactThick
      +, FragmentTbl, Generate2, HeavyG2charge, HeavyG2code
-     +, HeavyG2massN, HeavyG2symbol, HowGeomag, HowIntNuc, IncreaseXsec
-     +, KEminObs2, Knockon, Kpicns, Kpilog, LpmBremEmin, LpmPairEmin
-     +, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD, MagE, MagN
-     +, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE, Moliere, Mudirp
-     +, MulLow, NoOfSites2, OffsetHeight, PathLimit, PrevEventNo
-     +, PtAvFrag, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse
-     +, SeedFileDev, SucInt, SucPw, TempDev, TraceDev, Truncc, Truncn
-     +, Truncx, UpsilonMin, X0, XaxisFromSouth
+     +, HeavyG2massN, HeavyG2symbol, HowGeomag, HowIntNuc
+     +, InclusiveFile, IncreaseXsec, KEminObs2, Knockon, Kpicns, Kpilog
+     +, LpmBremEmin, LpmPairEmin, LundPara, MagBrem, MagBremEmin
+     +, MagChgDist, MagD, MagE, MagN, MagPair, MagPairEmin, MaxComptonE
+     +, MaxPhotoE, Moliere, Mudirp, MulLow, NoOfSites2, OffsetHeight
+     +, PathLimit, PrevEventNo, PtAvFrag, PtAvNonInteNuc, RatioToE0
+     +, RecoilKineMinE, Reverse, SeedFileDev, SucInt, SucPw, TempDev
+     +, TraceDev, Truncc, Truncn, Truncx, UpsilonMin, X0
+     +, XaxisFromSouth
