@@ -1,7 +1,20 @@
+#include "Zmaxdef.h"
+
 c         rigidity cut related commons
 c     *******************************
       integer maxAzm, maxZen, maxDim
-      parameter (maxAzm = 37, maxZen=21, maxDim=maxAzm* maxZen)
+      parameter (
+#ifdef MAX_AZM
+     * maxAzm = MAX_AZM,
+#else
+     * maxAzm = 37, 
+#endif
+#ifdef MAX_ZEN
+     * maxZen=MAX_ZEN,
+#else
+     * maxZen=21,
+#endif
+     * maxDim=maxAzm* maxZen)
       real*8  RigCutTbl, DAzm, DZen, Longi, Latit
       integer	AzmSize, ZenSize
       real*8  MagDec, MinAzm, MinZen
